Renderable
Protocol for objects that can be rendered to string.
Usage
Renderable()Any object with a render method returning str satisfies this protocol.
Methods
| Name | Description |
|---|---|
| render() | Render this object as a string. |
render()
Render this object as a string.
Usage
render()Returns
str-
The rendered representation.